#!/bin/csh
# testscript -- runs the compiles and runs test suites on the Unix Icon 
# distribution, redirects all output to a file

  if ($#argv == 1 ) then
     switch ($argv[1])
        case sun3:
        case sun4:
	case sun4_solaris:
	case sun4_solar_gcc:
	case sun4_solar_clc:
        case next:
        case decstation:
        case dec_osf:
        case iris4d:
        case hp9000_s300:
	case hp_risc:
	case rs6000_aix:
        case symmetry:
	case convex:
           set testarch = $argv[1]
           breaksw
        default: 
                  echo 'Usage: testscript <architecture>'
                  echo '  one of: sun3 sun4 sun4_acc next decstation dec_osf iris4d hp9000_s300 hp9000_s800 rs6000_aix symmetry convex'
                  exit
    endsw
  else
    echo '  Usage: testscript <architecture>, where architecture is one of:'
    echo '   sun3 sun4 next decstation dec_osf iris4d hp9000_s300 hp9000_s800 symmetry convex'
    exit
  endif

# create output file name -- test architecture + .out

 set outfnm = ${testarch}\.Xout
 unalias rm
 rm -f ${outfnm} >>& /dev/null 

# get version information

 set version_id = `egrep -e 'define[ 	]*Version' src/h/version.h |                       sed 's/^#define[ 	]*Version[ 	]*//'`

 echo "************************************************************" >>&! $outfnm
 echo '' >>&! $outfnm
 echo "Output from test suite for Unix Icon distribution"  >>&! $outfnm
 echo "version: ${version_id} " >>&! $outfnm
 echo '' >>&! $outfnm
 echo "architecture:   ${testarch}" >>&! $outfnm
 echo '' >>&! $outfnm
 echo "hostname:  `uname -n` " >>&! $outfnm
 echo "working directory: `pwd` " >>&! $outfnm
 echo "tester: `whoami` " >>&! $outfnm
# echo "tester: $USER " >>&! $outfnm
 echo "date: `date` " >>&! $outfnm
 echo '' >>&! $outfnm
 echo '' >>&! $outfnm
 echo source code obtained by >>&! $outfnm
 /bin/cat ./tardate  >>&! $outfnm
 echo '' >>&! $outfnm
 echo environment variables: >>&! $outfnm
 printenv >>&! $outfnm
 echo '' >>&! $outfnm

 echo " " >>&! $outfnm
 echo "*********************************************************" >>&! $outfnm
 echo "Begin make" >>&! $outfnm
 echo "*********************************************************" >>&! $outfnm
 echo " " >>&! $outfnm
 echo "****** make Clean `date` *******" >>&! $outfnm
 make Clean >>&! $outfnm
 echo " " >>&! $outfnm
 echo "****** make X-Configure name=$testarch `date` *******" >>&! $outfnm
 make X-Configure name=$testarch >>&! $outfnm
 echo " " >>&! $outfnm
 echo "****** make Icon  `date` *******" >>&! $outfnm
 make Icon >>&! $outfnm
 echo " " >>&! $outfnm
 echo "****** Begin Test `date` *******" >>&! $outfnm
 make Test >>&! $outfnm
 echo "************** End Test *********************" >>&! $outfnm
 echo " " >>&! $outfnm
# echo " " >>&! $outfnm
# switch (${testarch})
#    case iris4d:
#     echo "****  No coexpression capability for ${testarch} architecture  ****" >>&! $outfnm
#     breaksw
#    default:
echo "****** Begin Test-coexpr `date` *******" >>&! $outfnm
make Test-coexpr >>&! $outfnm
echo "************** End Test-coexpr *********************" >>&! $outfnm
#     breaksw
# endsw
 echo "****** Begin Benchmark `date` *******" >>&! $outfnm
 make Benchmark  >>&! ${outfnm}
echo "************* End Benchmark *********************" >>&! $outfnm
echo " " >>&! $outfnm
echo tarring bin directory >>&! $outfnm
echo " " >>&! $outfnm
tar -cf ${testarch}.bin.tar bin

#mv -f bin/iconc bin/iconc.${testarch}.X
#mv -f bin/icont bin/icont.${testarch}.X
#mv -f bin/iconx bin/iconx.${testarch}.X
#mv -f bin/dlrgint.o bin/dlrgint.o.${testarch}.X
#mv -f bin/icon_vt bin/icon_vt.${testarch}.X
#mv -f bin/rt.a bin/rt.a.${testarch}.X
#mv -f bin/rt.db bin/rt.db.${testarch}.X
#mv -f bin/rt.h bin/rt.h.${testarch}.X
#mv -f bin/rtt bin/rtt.${testarch}.X
#mv -f bin/libXpm.a bin/libXpm.a.${testarch}.X
#mv -f bin/patchstr bin/patchstr.${testarch}.X
echo "**** End of test for Icon distribution on ${testarch} architecture ****"   >>&! $outfnm
echo Version:  >>&! $outfnm
echo $version_id  >>&! $outfnm
echo "********************** `date` *********************"   >>&! $outfnm


